# WorkEvolveApi.AddressBookApi

All URIs are relative to *http://localhost/websiteapi/sourcecode/public/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getAddressBookById**](AddressBookApi.md#getAddressBookById) | **GET** /tenants/{tenantId}/addressbooks/{addressBookId} | Get an addressbook resource by id
[**getAllAddressBooks**](AddressBookApi.md#getAllAddressBooks) | **POST** /tenants/{tenantId}/addressbooks/get | Get all addressbooks resource
[**removeAddressBookById**](AddressBookApi.md#removeAddressBookById) | **DELETE** /tenants/{tenantId}/addressbooks/{addressBookId} | Delete addressbook resource by id
[**saveAddressBook**](AddressBookApi.md#saveAddressBook) | **POST** /tenants/{tenantId}/addressbooks | Save a new addressbook resource
[**updateAddressBook**](AddressBookApi.md#updateAddressBook) | **POST** /tenants/{tenantId}/addressbooks/{addressBookId} | Update addressbook resource by id


<a name="getAddressBookById"></a>
# **getAddressBookById**
> getAddressBookById(tenantId, addressBookId)

Get an addressbook resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.AddressBookApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var addressBookId = "addressBookId_example"; // String | ID of addressbook to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getAddressBookById(tenantId, addressBookId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **addressBookId** | **String**| ID of addressbook to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getAllAddressBooks"></a>
# **getAllAddressBooks**
> getAllAddressBooks(tenantId, opts)

Get all addressbooks resource

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.AddressBookApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var opts = { 
  'filter': null, // Object | Filter addressbooks by condition provided
  'offset': 0, // Number | The number of items to skip before starting to collect the result set
  'limit': 25 // Number | The number of items to return
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getAllAddressBooks(tenantId, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **filter** | **Object**| Filter addressbooks by condition provided | [optional] 
 **offset** | **Number**| The number of items to skip before starting to collect the result set | [optional] [default to 0]
 **limit** | **Number**| The number of items to return | [optional] [default to 25]

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="removeAddressBookById"></a>
# **removeAddressBookById**
> removeAddressBookById(tenantId, addressBookId)

Delete addressbook resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.AddressBookApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var addressBookId = "addressBookId_example"; // String | ID of addressbook to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.removeAddressBookById(tenantId, addressBookId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **addressBookId** | **String**| ID of addressbook to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="saveAddressBook"></a>
# **saveAddressBook**
> saveAddressBook(tenantId, data)

Save a new addressbook resource

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.AddressBookApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var data = null; // Object | Provide your addressbook data information to save


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.saveAddressBook(tenantId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **data** | **Object**| Provide your addressbook data information to save | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="updateAddressBook"></a>
# **updateAddressBook**
> updateAddressBook(tenantId, addressBookId, data)

Update addressbook resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.AddressBookApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var addressBookId = "addressBookId_example"; // String | ID of addressbook to filter by

var data = null; // Object | Provide your addressbook data information to update


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.updateAddressBook(tenantId, addressBookId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **addressBookId** | **String**| ID of addressbook to filter by | 
 **data** | **Object**| Provide your addressbook data information to update | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

