# WorkEvolveApi.DataRevisionApi

All URIs are relative to *http://localhost/websiteapi/sourcecode/public/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getAllEvents**](DataRevisionApi.md#getAllEvents) | **GET** /tenants/{tenantId}/events | Get all events
[**getDataByEvent**](DataRevisionApi.md#getDataByEvent) | **GET** /tenants/{tenantId}/events/{event} | Get data by specific event
[**getDataByRevision**](DataRevisionApi.md#getDataByRevision) | **GET** /tenants/{tenantId}/{resource}/{resourceId}/revisions/{revision} | Get data of an item by specific revision
[**getDataFromAllRevisions**](DataRevisionApi.md#getDataFromAllRevisions) | **GET** /tenants/{tenantId}/{resource}/{resourceId}/revisions | Get data of an item from all revisions
[**getDataRevisionGroupByVersionNo**](DataRevisionApi.md#getDataRevisionGroupByVersionNo) | **POST** /tenants/{tenantId}/{resource}/{resourceId}/revisions/get | Get data of an item from all revisions that group by revision No
[**getDifferencesByRevision**](DataRevisionApi.md#getDifferencesByRevision) | **GET** /tenants/{tenantId}/{resource}/{resourceId}/revisions/{revisionFrom}/{revisionTo} | Get the difference in fields values between the two revisions
[**revertDataByEvent**](DataRevisionApi.md#revertDataByEvent) | **POST** /tenants/{tenantId}/events/{event}/revert | Reverts the item to the values in the given event. This will undo any changes made after the given event.
[**revertDataByRevision**](DataRevisionApi.md#revertDataByRevision) | **POST** /tenants/{tenantId}/{resource}/{resourceId}/revisions/{revision}/revert | Reverts the item to the values in the given revision. This will undo any changes made after the given revision.


<a name="getAllEvents"></a>
# **getAllEvents**
> getAllEvents(tenantId, opts)

Get all events

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.DataRevisionApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var opts = { 
  'offset': 0, // Number | The number of items to skip before starting to collect the result set
  'limit': 25 // Number | The number of items to return
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getAllEvents(tenantId, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **offset** | **Number**| The number of items to skip before starting to collect the result set | [optional] [default to 0]
 **limit** | **Number**| The number of items to return | [optional] [default to 25]

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDataByEvent"></a>
# **getDataByEvent**
> getDataByEvent(tenantId, event)

Get data by specific event

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.DataRevisionApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var event = "event_example"; // String | Event to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getDataByEvent(tenantId, event, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **event** | **String**| Event to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDataByRevision"></a>
# **getDataByRevision**
> getDataByRevision(tenantId, resource, resourceId, revision, opts)

Get data of an item by specific revision

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.DataRevisionApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach revision

var resourceId = "resourceId_example"; // String | ID of resource to attach revision

var revision = "revision_example"; // String | Revision to filter by

var opts = { 
  'offset': 0, // Number | The number of items to skip before starting to collect the result set
  'limit': 25 // Number | The number of items to return
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getDataByRevision(tenantId, resource, resourceId, revision, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach revision | 
 **resourceId** | **String**| ID of resource to attach revision | 
 **revision** | **String**| Revision to filter by | 
 **offset** | **Number**| The number of items to skip before starting to collect the result set | [optional] [default to 0]
 **limit** | **Number**| The number of items to return | [optional] [default to 25]

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDataFromAllRevisions"></a>
# **getDataFromAllRevisions**
> getDataFromAllRevisions(tenantId, resource, resourceId, opts)

Get data of an item from all revisions

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.DataRevisionApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach revision

var resourceId = "resourceId_example"; // String | ID of resource to attach revision

var opts = { 
  'offset': 0, // Number | The number of items to skip before starting to collect the result set
  'limit': 25 // Number | The number of items to return
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getDataFromAllRevisions(tenantId, resource, resourceId, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach revision | 
 **resourceId** | **String**| ID of resource to attach revision | 
 **offset** | **Number**| The number of items to skip before starting to collect the result set | [optional] [default to 0]
 **limit** | **Number**| The number of items to return | [optional] [default to 25]

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDataRevisionGroupByVersionNo"></a>
# **getDataRevisionGroupByVersionNo**
> getDataRevisionGroupByVersionNo(tenantId, resource, resourceId, opts)

Get data of an item from all revisions that group by revision No

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.DataRevisionApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach revision

var resourceId = "resourceId_example"; // String | ID of resource to attach revision

var opts = { 
  'offset': 0, // Number | The number of items to skip before starting to collect the result set
  'limit': 25 // Number | The number of items to return
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getDataRevisionGroupByVersionNo(tenantId, resource, resourceId, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach revision | 
 **resourceId** | **String**| ID of resource to attach revision | 
 **offset** | **Number**| The number of items to skip before starting to collect the result set | [optional] [default to 0]
 **limit** | **Number**| The number of items to return | [optional] [default to 25]

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDifferencesByRevision"></a>
# **getDifferencesByRevision**
> getDifferencesByRevision(tenantId, resource, resourceId, revisionFrom, revisionTo, opts)

Get the difference in fields values between the two revisions

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.DataRevisionApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach revision

var resourceId = "resourceId_example"; // String | ID of resource to attach revision

var revisionFrom = "revisionFrom_example"; // String | Revision from to filter by

var revisionTo = "revisionTo_example"; // String | Revision to to filter by

var opts = { 
  'offset': 0, // Number | The number of items to skip before starting to collect the result set
  'limit': 25 // Number | The number of items to return
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getDifferencesByRevision(tenantId, resource, resourceId, revisionFrom, revisionTo, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach revision | 
 **resourceId** | **String**| ID of resource to attach revision | 
 **revisionFrom** | **String**| Revision from to filter by | 
 **revisionTo** | **String**| Revision to to filter by | 
 **offset** | **Number**| The number of items to skip before starting to collect the result set | [optional] [default to 0]
 **limit** | **Number**| The number of items to return | [optional] [default to 25]

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="revertDataByEvent"></a>
# **revertDataByEvent**
> revertDataByEvent(tenantId, event)

Reverts the item to the values in the given event. This will undo any changes made after the given event.

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.DataRevisionApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var event = "event_example"; // String | Event to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.revertDataByEvent(tenantId, event, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **event** | **String**| Event to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="revertDataByRevision"></a>
# **revertDataByRevision**
> revertDataByRevision(tenantId, resource, resourceId, revision)

Reverts the item to the values in the given revision. This will undo any changes made after the given revision.

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.DataRevisionApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach revision

var resourceId = "resourceId_example"; // String | ID of resource to attach revision

var revision = "revision_example"; // String | Revision to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.revertDataByRevision(tenantId, resource, resourceId, revision, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach revision | 
 **resourceId** | **String**| ID of resource to attach revision | 
 **revision** | **String**| Revision to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

