# WorkEvolveApi.FormApi

All URIs are relative to *http://localhost/websiteapi/sourcecode/public/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getAllForms**](FormApi.md#getAllForms) | **POST** /programs/{proId}/forms/get | Get all forms resource
[**getFormById**](FormApi.md#getFormById) | **GET** /programs/{proId}/forms/{formId} | Get a form resource by id
[**removeFormById**](FormApi.md#removeFormById) | **DELETE** /programs/{proId}/forms/{formId} | Delete form resource by id
[**saveForm**](FormApi.md#saveForm) | **POST** /programs/{proId}/forms | Save a new form resource
[**updateForm**](FormApi.md#updateForm) | **POST** /programs/{proId}/forms/{formId} | Update form resource by id


<a name="getAllForms"></a>
# **getAllForms**
> getAllForms(proId, opts)

Get all forms resource

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.FormApi();

var proId = "proId_example"; // String | ID of program to filter by

var opts = { 
  'filter': null, // Object | Filter forms by condition provided
  'offset': 0, // Number | The number of items to skip before starting to collect the result set
  'limit': 25 // Number | The number of items to return
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getAllForms(proId, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **proId** | **String**| ID of program to filter by | 
 **filter** | **Object**| Filter forms by condition provided | [optional] 
 **offset** | **Number**| The number of items to skip before starting to collect the result set | [optional] [default to 0]
 **limit** | **Number**| The number of items to return | [optional] [default to 25]

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getFormById"></a>
# **getFormById**
> getFormById(proId, formId)

Get a form resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.FormApi();

var proId = "proId_example"; // String | ID of program to filter by

var formId = "formId_example"; // String | ID of form to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getFormById(proId, formId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **proId** | **String**| ID of program to filter by | 
 **formId** | **String**| ID of form to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="removeFormById"></a>
# **removeFormById**
> removeFormById(proId, formId)

Delete form resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.FormApi();

var proId = "proId_example"; // String | ID of program to filter by

var formId = "formId_example"; // String | ID of form to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.removeFormById(proId, formId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **proId** | **String**| ID of program to filter by | 
 **formId** | **String**| ID of form to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="saveForm"></a>
# **saveForm**
> saveForm(proId, data)

Save a new form resource

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.FormApi();

var proId = "proId_example"; // String | ID of program to filter by

var data = null; // Object | Provide your form data information to save


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.saveForm(proId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **proId** | **String**| ID of program to filter by | 
 **data** | **Object**| Provide your form data information to save | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="updateForm"></a>
# **updateForm**
> updateForm(proId, formId, data)

Update form resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.FormApi();

var proId = "proId_example"; // String | ID of program to filter by

var formId = "formId_example"; // String | ID of form to filter by

var data = null; // Object | Provide your form data information to update


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.updateForm(proId, formId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **proId** | **String**| ID of program to filter by | 
 **formId** | **String**| ID of form to filter by | 
 **data** | **Object**| Provide your form data information to update | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

