# WorkEvolveApi.InvitationApi

All URIs are relative to *http://localhost/websiteapi/sourcecode/public/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**acceptInvitation**](InvitationApi.md#acceptInvitation) | **POST** /invitations/{tokenId}/accept | Accept an invitation resource
[**getInvitationByTokenId**](InvitationApi.md#getInvitationByTokenId) | **GET** /invitations/{tokenId}/get | Get an invitation resource by token id
[**reSendInvitation**](InvitationApi.md#reSendInvitation) | **POST** /invitations/{userId} | Resend an invitation resource
[**removeInvitation**](InvitationApi.md#removeInvitation) | **DELETE** /invitations/{userId} | Remove an invitation resource
[**sendInvitation**](InvitationApi.md#sendInvitation) | **POST** /invitations | Send a new invitation resource


<a name="acceptInvitation"></a>
# **acceptInvitation**
> acceptInvitation(tokenId)

Accept an invitation resource

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.InvitationApi();

var tokenId = "tokenId_example"; // String | ID of token to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.acceptInvitation(tokenId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tokenId** | **String**| ID of token to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getInvitationByTokenId"></a>
# **getInvitationByTokenId**
> getInvitationByTokenId(tokenId)

Get an invitation resource by token id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.InvitationApi();

var tokenId = "tokenId_example"; // String | ID of token to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getInvitationByTokenId(tokenId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tokenId** | **String**| ID of token to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="reSendInvitation"></a>
# **reSendInvitation**
> reSendInvitation(userId, data)

Resend an invitation resource

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.InvitationApi();

var userId = "userId_example"; // String | ID of user to resend invitation

var data = null; // Object | Provide your invitation data information to resend


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.reSendInvitation(userId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **userId** | **String**| ID of user to resend invitation | 
 **data** | **Object**| Provide your invitation data information to resend | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="removeInvitation"></a>
# **removeInvitation**
> removeInvitation(userId, data)

Remove an invitation resource

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.InvitationApi();

var userId = "userId_example"; // String | ID of user to remove invitation

var data = null; // Object | Provide your tenant data information


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.removeInvitation(userId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **userId** | **String**| ID of user to remove invitation | 
 **data** | **Object**| Provide your tenant data information | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="sendInvitation"></a>
# **sendInvitation**
> sendInvitation(data)

Send a new invitation resource

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.InvitationApi();

var data = null; // Object | Provide your invitation data information to send


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.sendInvitation(data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **data** | **Object**| Provide your invitation data information to send | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

