# WorkEvolveApi.PostApi

All URIs are relative to *http://localhost/websiteapi/sourcecode/public/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getAllPosts**](PostApi.md#getAllPosts) | **POST** /tenants/{tenantId}/{resource}/{resourceId}/posts/get | Get all posts resource
[**getPostById**](PostApi.md#getPostById) | **GET** /tenants/{tenantId}/{resource}/{resourceId}/posts/{postId} | Get a post resource by id
[**savePost**](PostApi.md#savePost) | **POST** /tenants/{tenantId}/{resource}/{resourceId}/posts | Save a new post resource
[**updatePost**](PostApi.md#updatePost) | **POST** /tenants/{tenantId}/{resource}/{resourceId}/posts/{postId} | Update post resource by id


<a name="getAllPosts"></a>
# **getAllPosts**
> getAllPosts(tenantId, resource, resourceId, opts)

Get all posts resource

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.PostApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach post

var resourceId = "resourceId_example"; // String | ID of resource to attach post

var opts = { 
  'offset': 0, // Number | The number of items to skip before starting to collect the result set
  'limit': 25 // Number | The number of items to return
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getAllPosts(tenantId, resource, resourceId, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach post | 
 **resourceId** | **String**| ID of resource to attach post | 
 **offset** | **Number**| The number of items to skip before starting to collect the result set | [optional] [default to 0]
 **limit** | **Number**| The number of items to return | [optional] [default to 25]

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getPostById"></a>
# **getPostById**
> getPostById(tenantId, resource, resourceId, postId)

Get a post resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.PostApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach post

var resourceId = "resourceId_example"; // String | ID of resource to attach post

var postId = "postId_example"; // String | ID of post to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getPostById(tenantId, resource, resourceId, postId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach post | 
 **resourceId** | **String**| ID of resource to attach post | 
 **postId** | **String**| ID of post to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="savePost"></a>
# **savePost**
> savePost(tenantId, resource, resourceId, data)

Save a new post resource

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.PostApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach post

var resourceId = "resourceId_example"; // String | ID of resource to attach post

var data = null; // Object | Provide your post data information to save


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.savePost(tenantId, resource, resourceId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach post | 
 **resourceId** | **String**| ID of resource to attach post | 
 **data** | **Object**| Provide your post data information to save | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="updatePost"></a>
# **updatePost**
> updatePost(tenantId, resource, resourceId, postId, data)

Update post resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.PostApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach post

var resourceId = "resourceId_example"; // String | ID of resource to attach post

var postId = "postId_example"; // String | ID of post to filter by

var data = null; // Object | Provide your post data information to update


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.updatePost(tenantId, resource, resourceId, postId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach post | 
 **resourceId** | **String**| ID of resource to attach post | 
 **postId** | **String**| ID of post to filter by | 
 **data** | **Object**| Provide your post data information to update | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

