# WorkEvolveApi.ProjectApi

All URIs are relative to *http://localhost/websiteapi/sourcecode/public/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getAllProjects**](ProjectApi.md#getAllProjects) | **POST** /tenants/{tenantId}/projects/get | Get all projects resource
[**getProjectById**](ProjectApi.md#getProjectById) | **GET** /tenants/{tenantId}/projects/{projectId} | Get a project resource by id
[**saveProject**](ProjectApi.md#saveProject) | **POST** /tenants/{tenantId}/projects | Save a new project resource
[**updateProject**](ProjectApi.md#updateProject) | **POST** /tenants/{tenantId}/projects/{projectId} | Update project resource by id


<a name="getAllProjects"></a>
# **getAllProjects**
> getAllProjects(tenantId, opts)

Get all projects resource

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.ProjectApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var opts = { 
  'filter': null, // Object | Filter projects by condition provided
  'offset': 0, // Number | The number of items to skip before starting to collect the result set
  'limit': 25 // Number | The number of items to return
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getAllProjects(tenantId, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **filter** | **Object**| Filter projects by condition provided | [optional] 
 **offset** | **Number**| The number of items to skip before starting to collect the result set | [optional] [default to 0]
 **limit** | **Number**| The number of items to return | [optional] [default to 25]

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getProjectById"></a>
# **getProjectById**
> getProjectById(tenantId, projectId)

Get a project resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.ProjectApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var projectId = "projectId_example"; // String | ID of project to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getProjectById(tenantId, projectId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **projectId** | **String**| ID of project to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="saveProject"></a>
# **saveProject**
> saveProject(tenantId, data)

Save a new project resource

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.ProjectApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var data = null; // Object | Provide your project data information to save


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.saveProject(tenantId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **data** | **Object**| Provide your project data information to save | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="updateProject"></a>
# **updateProject**
> updateProject(tenantId, projectId, data)

Update project resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.ProjectApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var projectId = "projectId_example"; // String | ID of project to filter by

var data = null; // Object | Provide your project data information to update


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.updateProject(tenantId, projectId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **projectId** | **String**| ID of project to filter by | 
 **data** | **Object**| Provide your project data information to update | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

