# WorkEvolveApi.ReactionApi

All URIs are relative to *http://localhost/websiteapi/sourcecode/public/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getAllReactions**](ReactionApi.md#getAllReactions) | **POST** /tenants/{tenantId}/{resource}/{resourceId}/reactions/get | Get all reactions resource
[**getReactionById**](ReactionApi.md#getReactionById) | **GET** /tenants/{tenantId}/{resource}/{resourceId}/reactions/{reactionId} | Get a reaction resource by id
[**removeReactoinById**](ReactionApi.md#removeReactoinById) | **DELETE** /tenants/{tenantId}/{resource}/{resourceId}/reactions/{reactionId} | Delete reaction resource by id
[**saveReaction**](ReactionApi.md#saveReaction) | **POST** /tenants/{tenantId}/{resource}/{resourceId}/reactions | Save a new reaction resource
[**updateReaction**](ReactionApi.md#updateReaction) | **POST** /tenants/{tenantId}/{resource}/{resourceId}/reactions/{reactionId} | Update reaction resource by id


<a name="getAllReactions"></a>
# **getAllReactions**
> getAllReactions(tenantId, resource, resourceId, opts)

Get all reactions resource

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.ReactionApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach reaction

var resourceId = "resourceId_example"; // String | ID of resource to attach reaction

var opts = { 
  'filter': null, // Object | Filter reactions by condition provided
  'offset': 0, // Number | The number of items to skip before starting to collect the result set
  'limit': 25 // Number | The number of items to return
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getAllReactions(tenantId, resource, resourceId, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach reaction | 
 **resourceId** | **String**| ID of resource to attach reaction | 
 **filter** | **Object**| Filter reactions by condition provided | [optional] 
 **offset** | **Number**| The number of items to skip before starting to collect the result set | [optional] [default to 0]
 **limit** | **Number**| The number of items to return | [optional] [default to 25]

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getReactionById"></a>
# **getReactionById**
> getReactionById(tenantId, resource, resourceId, reactionId)

Get a reaction resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.ReactionApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach reaction

var resourceId = "resourceId_example"; // String | ID of resource to attach reaction

var reactionId = "reactionId_example"; // String | ID of reaction to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getReactionById(tenantId, resource, resourceId, reactionId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach reaction | 
 **resourceId** | **String**| ID of resource to attach reaction | 
 **reactionId** | **String**| ID of reaction to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="removeReactoinById"></a>
# **removeReactoinById**
> removeReactoinById(tenantId, resource, resourceId, reactionId)

Delete reaction resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.ReactionApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach reaction

var resourceId = "resourceId_example"; // String | ID of resource to attach reaction

var reactionId = "reactionId_example"; // String | ID of reaction to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.removeReactoinById(tenantId, resource, resourceId, reactionId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach reaction | 
 **resourceId** | **String**| ID of resource to attach reaction | 
 **reactionId** | **String**| ID of reaction to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="saveReaction"></a>
# **saveReaction**
> saveReaction(tenantId, resource, resourceId, data)

Save a new reaction resource

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.ReactionApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach reaction

var resourceId = "resourceId_example"; // String | ID of resource to attach reaction

var data = null; // Object | Provide your reaction data information to save


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.saveReaction(tenantId, resource, resourceId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach reaction | 
 **resourceId** | **String**| ID of resource to attach reaction | 
 **data** | **Object**| Provide your reaction data information to save | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="updateReaction"></a>
# **updateReaction**
> updateReaction(tenantId, resource, resourceId, reactionId, data)

Update reaction resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.ReactionApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach reaction

var resourceId = "resourceId_example"; // String | ID of resource to attach reaction

var reactionId = "reactionId_example"; // String | ID of reaction to filter by

var data = null; // Object | Provide your reaction data information to update


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.updateReaction(tenantId, resource, resourceId, reactionId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach reaction | 
 **resourceId** | **String**| ID of resource to attach reaction | 
 **reactionId** | **String**| ID of reaction to filter by | 
 **data** | **Object**| Provide your reaction data information to update | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

