# WorkEvolveApi.ReplyApi

All URIs are relative to *http://localhost/websiteapi/sourcecode/public/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getAllReplies**](ReplyApi.md#getAllReplies) | **POST** /tenants/{tenantId}/{resource}/{resourceId}/posts/{postId}/replies/get | Get all replies resource
[**getReplyById**](ReplyApi.md#getReplyById) | **GET** /tenants/{tenantId}/{resource}/{resourceId}/posts/{postId}/replies/{replyId} | Get a reply resource by id
[**saveReply**](ReplyApi.md#saveReply) | **POST** /tenants/{tenantId}/{resource}/{resourceId}/posts/{postId}/replies | Save a new reply resource
[**updateReply**](ReplyApi.md#updateReply) | **POST** /tenants/{tenantId}/{resource}/{resourceId}/posts/{postId}/replies/{replyId} | Update reply resource by id


<a name="getAllReplies"></a>
# **getAllReplies**
> getAllReplies(tenantId, resource, resourceId, postId, opts)

Get all replies resource

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.ReplyApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach post

var resourceId = "resourceId_example"; // String | ID of resource to attach post

var postId = "postId_example"; // String | ID of post to filter by

var opts = { 
  'offset': 0, // Number | The number of items to skip before starting to collect the result set
  'limit': 25 // Number | The number of items to return
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getAllReplies(tenantId, resource, resourceId, postId, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach post | 
 **resourceId** | **String**| ID of resource to attach post | 
 **postId** | **String**| ID of post to filter by | 
 **offset** | **Number**| The number of items to skip before starting to collect the result set | [optional] [default to 0]
 **limit** | **Number**| The number of items to return | [optional] [default to 25]

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getReplyById"></a>
# **getReplyById**
> getReplyById(tenantId, resource, resourceId, postId, replyId)

Get a reply resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.ReplyApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach post

var resourceId = "resourceId_example"; // String | ID of resource to attach post

var postId = "postId_example"; // String | ID of post to filter by

var replyId = "replyId_example"; // String | ID of reply to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getReplyById(tenantId, resource, resourceId, postId, replyId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach post | 
 **resourceId** | **String**| ID of resource to attach post | 
 **postId** | **String**| ID of post to filter by | 
 **replyId** | **String**| ID of reply to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="saveReply"></a>
# **saveReply**
> saveReply(tenantId, resource, resourceId, postId, data)

Save a new reply resource

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.ReplyApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach post

var resourceId = "resourceId_example"; // String | ID of resource to attach post

var postId = "postId_example"; // String | ID of post to filter by

var data = null; // Object | Provide your reply data information to save


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.saveReply(tenantId, resource, resourceId, postId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach post | 
 **resourceId** | **String**| ID of resource to attach post | 
 **postId** | **String**| ID of post to filter by | 
 **data** | **Object**| Provide your reply data information to save | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="updateReply"></a>
# **updateReply**
> updateReply(tenantId, resource, resourceId, postId, replyId, data)

Update reply resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.ReplyApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach post

var resourceId = "resourceId_example"; // String | ID of resource to attach post

var postId = "postId_example"; // String | ID of post to filter by

var replyId = "replyId_example"; // String | ID of reply to filter by

var data = null; // Object | Provide your reply data information to update


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.updateReply(tenantId, resource, resourceId, postId, replyId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach post | 
 **resourceId** | **String**| ID of resource to attach post | 
 **postId** | **String**| ID of post to filter by | 
 **replyId** | **String**| ID of reply to filter by | 
 **data** | **Object**| Provide your reply data information to update | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

