# WorkEvolveApi.TaskApi

All URIs are relative to *http://localhost/websiteapi/sourcecode/public/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getAllTasks**](TaskApi.md#getAllTasks) | **POST** /tenants/{tenantId}/{resource}/{resourceId}/tasks/get | Get all tasks resource
[**getTaskById**](TaskApi.md#getTaskById) | **GET** /tenants/{tenantId}/{resource}/{resourceId}/tasks/{taskId} | Get a task resource by id
[**removeTaskById**](TaskApi.md#removeTaskById) | **DELETE** /tenants/{tenantId}/{resource}/{resourceId}/tasks/{taskId} | Delete task resource by id
[**saveTask**](TaskApi.md#saveTask) | **POST** /tenants/{tenantId}/{resource}/{resourceId}/tasks | Save a new task resource
[**updateTask**](TaskApi.md#updateTask) | **POST** /tenants/{tenantId}/{resource}/{resourceId}/tasks/{taskId} | Update task resource by id


<a name="getAllTasks"></a>
# **getAllTasks**
> getAllTasks(tenantId, resource, resourceId, opts)

Get all tasks resource

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.TaskApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach task

var resourceId = "resourceId_example"; // String | ID of resource to attach task

var opts = { 
  'filter': null, // Object | Filter tasks by condition provided
  'offset': 0, // Number | The number of items to skip before starting to collect the result set
  'limit': 25 // Number | The number of items to return
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getAllTasks(tenantId, resource, resourceId, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach task | 
 **resourceId** | **String**| ID of resource to attach task | 
 **filter** | **Object**| Filter tasks by condition provided | [optional] 
 **offset** | **Number**| The number of items to skip before starting to collect the result set | [optional] [default to 0]
 **limit** | **Number**| The number of items to return | [optional] [default to 25]

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getTaskById"></a>
# **getTaskById**
> getTaskById(tenantId, resource, resourceId, taskId)

Get a task resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.TaskApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach task

var resourceId = "resourceId_example"; // String | ID of resource to attach task

var taskId = "taskId_example"; // String | ID of task to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getTaskById(tenantId, resource, resourceId, taskId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach task | 
 **resourceId** | **String**| ID of resource to attach task | 
 **taskId** | **String**| ID of task to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="removeTaskById"></a>
# **removeTaskById**
> removeTaskById(tenantId, resource, resourceId, taskId)

Delete task resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.TaskApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach task

var resourceId = "resourceId_example"; // String | ID of resource to attach task

var taskId = "taskId_example"; // String | ID of task to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.removeTaskById(tenantId, resource, resourceId, taskId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach task | 
 **resourceId** | **String**| ID of resource to attach task | 
 **taskId** | **String**| ID of task to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="saveTask"></a>
# **saveTask**
> saveTask(tenantId, resource, resourceId, data)

Save a new task resource

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.TaskApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach task

var resourceId = "resourceId_example"; // String | ID of resource to attach task

var data = null; // Object | Provide your task data information to save


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.saveTask(tenantId, resource, resourceId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach task | 
 **resourceId** | **String**| ID of resource to attach task | 
 **data** | **Object**| Provide your task data information to save | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="updateTask"></a>
# **updateTask**
> updateTask(tenantId, resource, resourceId, taskId, data)

Update task resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.TaskApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var resource = "resource_example"; // String | Name of resource to attach task

var resourceId = "resourceId_example"; // String | ID of resource to attach task

var taskId = "taskId_example"; // String | ID of task to filter by

var data = null; // Object | Provide your task data information to update


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.updateTask(tenantId, resource, resourceId, taskId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **resource** | **String**| Name of resource to attach task | 
 **resourceId** | **String**| ID of resource to attach task | 
 **taskId** | **String**| ID of task to filter by | 
 **data** | **Object**| Provide your task data information to update | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

