# WorkEvolveApi.UdcValueApi

All URIs are relative to *http://localhost/websiteapi/sourcecode/public/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getAllUdcValues**](UdcValueApi.md#getAllUdcValues) | **POST** /systems/{sysCode}/types/{typeId}/values/get | Get all udc values resource without tenant
[**getAllUdcValuesTenant**](UdcValueApi.md#getAllUdcValuesTenant) | **POST** /tenants/{tenantId}/systems/{sysCode}/types/{typeId}/values/get | Get all udc values resource with tenant
[**getUdcValueById**](UdcValueApi.md#getUdcValueById) | **GET** /systems/{sysCode}/types/{typeId}/values/{valueId} | Get udc value resource without tenant by id
[**getUdcValueTenantById**](UdcValueApi.md#getUdcValueTenantById) | **GET** /tenants/{tenantId}/systems/{sysCode}/types/{typeId}/values/{valueId} | Get udc value resource with tenant by id
[**removeUdcValueById**](UdcValueApi.md#removeUdcValueById) | **DELETE** /systems/{sysCode}/types/{typeId}/values/{valueId} | Delete udc value resource without tenant by id
[**removeUdcValueTenantById**](UdcValueApi.md#removeUdcValueTenantById) | **DELETE** /tenants/{tenantId}/systems/{sysCode}/types/{typeId}/values/{valueId} | Delete udc value resource with tenant by id
[**saveUdcValue**](UdcValueApi.md#saveUdcValue) | **POST** /systems/{sysCode}/types/{typeId}/values | Save a new udc value resource without tenant
[**saveUdcValueTenant**](UdcValueApi.md#saveUdcValueTenant) | **POST** /tenants/{tenantId}/systems/{sysCode}/types/{typeId}/values | Save a new udc value resource with tenant
[**updateUdcValue**](UdcValueApi.md#updateUdcValue) | **POST** /systems/{sysCode}/types/{typeId}/values/{valueId} | Update udc value resource without tenant by id
[**updateUdcValueTenant**](UdcValueApi.md#updateUdcValueTenant) | **POST** /tenants/{tenantId}/systems/{sysCode}/types/{typeId}/values/{valueId} | Update udc value resource with tenant by id


<a name="getAllUdcValues"></a>
# **getAllUdcValues**
> getAllUdcValues(sysCode, typeId, opts)

Get all udc values resource without tenant

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.UdcValueApi();

var sysCode = "sysCode_example"; // String | Code of system to filter by

var typeId = "typeId_example"; // String | ID of udc type to filter by

var opts = { 
  'filter': null, // Object | Filter udc value by condition provided
  'offset': 0, // Number | The number of items to skip before starting to collect the result set
  'limit': 25 // Number | The number of items to return
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getAllUdcValues(sysCode, typeId, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sysCode** | **String**| Code of system to filter by | 
 **typeId** | **String**| ID of udc type to filter by | 
 **filter** | **Object**| Filter udc value by condition provided | [optional] 
 **offset** | **Number**| The number of items to skip before starting to collect the result set | [optional] [default to 0]
 **limit** | **Number**| The number of items to return | [optional] [default to 25]

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getAllUdcValuesTenant"></a>
# **getAllUdcValuesTenant**
> getAllUdcValuesTenant(tenantId, sysCode, typeId, opts)

Get all udc values resource with tenant

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.UdcValueApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var sysCode = "sysCode_example"; // String | Code of system to filter by

var typeId = "typeId_example"; // String | ID of udc type to filter by

var opts = { 
  'filter': null, // Object | Filter udc value by condition provided
  'offset': 0, // Number | The number of items to skip before starting to collect the result set
  'limit': 25 // Number | The number of items to return
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getAllUdcValuesTenant(tenantId, sysCode, typeId, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **sysCode** | **String**| Code of system to filter by | 
 **typeId** | **String**| ID of udc type to filter by | 
 **filter** | **Object**| Filter udc value by condition provided | [optional] 
 **offset** | **Number**| The number of items to skip before starting to collect the result set | [optional] [default to 0]
 **limit** | **Number**| The number of items to return | [optional] [default to 25]

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getUdcValueById"></a>
# **getUdcValueById**
> getUdcValueById(sysCode, typeId, valueId)

Get udc value resource without tenant by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.UdcValueApi();

var sysCode = "sysCode_example"; // String | Code of system to filter by

var typeId = "typeId_example"; // String | ID of udc type to filter by

var valueId = "valueId_example"; // String | ID of udc value to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getUdcValueById(sysCode, typeId, valueId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sysCode** | **String**| Code of system to filter by | 
 **typeId** | **String**| ID of udc type to filter by | 
 **valueId** | **String**| ID of udc value to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getUdcValueTenantById"></a>
# **getUdcValueTenantById**
> getUdcValueTenantById(tenantId, sysCode, typeId, valueId)

Get udc value resource with tenant by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.UdcValueApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var sysCode = "sysCode_example"; // String | Code of system to filter by

var typeId = "typeId_example"; // String | ID of udc type to filter by

var valueId = "valueId_example"; // String | ID of udc value to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getUdcValueTenantById(tenantId, sysCode, typeId, valueId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **sysCode** | **String**| Code of system to filter by | 
 **typeId** | **String**| ID of udc type to filter by | 
 **valueId** | **String**| ID of udc value to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="removeUdcValueById"></a>
# **removeUdcValueById**
> removeUdcValueById(sysCode, typeId, valueId)

Delete udc value resource without tenant by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.UdcValueApi();

var sysCode = "sysCode_example"; // String | Code of system to filter by

var typeId = "typeId_example"; // String | ID of udc type to filter by

var valueId = "valueId_example"; // String | ID of udc value to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.removeUdcValueById(sysCode, typeId, valueId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sysCode** | **String**| Code of system to filter by | 
 **typeId** | **String**| ID of udc type to filter by | 
 **valueId** | **String**| ID of udc value to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="removeUdcValueTenantById"></a>
# **removeUdcValueTenantById**
> removeUdcValueTenantById(tenantId, sysCode, typeId, valueId)

Delete udc value resource with tenant by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.UdcValueApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var sysCode = "sysCode_example"; // String | Code of system to filter by

var typeId = "typeId_example"; // String | ID of udc type to filter by

var valueId = "valueId_example"; // String | ID of udc value to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.removeUdcValueTenantById(tenantId, sysCode, typeId, valueId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **sysCode** | **String**| Code of system to filter by | 
 **typeId** | **String**| ID of udc type to filter by | 
 **valueId** | **String**| ID of udc value to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="saveUdcValue"></a>
# **saveUdcValue**
> saveUdcValue(sysCode, typeId, data)

Save a new udc value resource without tenant

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.UdcValueApi();

var sysCode = "sysCode_example"; // String | Code of system to filter by

var typeId = "typeId_example"; // String | ID of udc type to filter by

var data = null; // Object | Provide your udc value data information to save


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.saveUdcValue(sysCode, typeId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sysCode** | **String**| Code of system to filter by | 
 **typeId** | **String**| ID of udc type to filter by | 
 **data** | **Object**| Provide your udc value data information to save | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="saveUdcValueTenant"></a>
# **saveUdcValueTenant**
> saveUdcValueTenant(tenantId, sysCode, typeId, data)

Save a new udc value resource with tenant

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.UdcValueApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var sysCode = "sysCode_example"; // String | Code of system to filter by

var typeId = "typeId_example"; // String | ID of udc type to filter by

var data = null; // Object | Provide your udc value data information to save


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.saveUdcValueTenant(tenantId, sysCode, typeId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **sysCode** | **String**| Code of system to filter by | 
 **typeId** | **String**| ID of udc type to filter by | 
 **data** | **Object**| Provide your udc value data information to save | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="updateUdcValue"></a>
# **updateUdcValue**
> updateUdcValue(sysCode, typeId, valueId, data)

Update udc value resource without tenant by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.UdcValueApi();

var sysCode = "sysCode_example"; // String | Code of system to filter by

var typeId = "typeId_example"; // String | ID of udc type to filter by

var valueId = "valueId_example"; // String | ID of udc value to filter by

var data = null; // Object | Provide your udc value data information to update


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.updateUdcValue(sysCode, typeId, valueId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sysCode** | **String**| Code of system to filter by | 
 **typeId** | **String**| ID of udc type to filter by | 
 **valueId** | **String**| ID of udc value to filter by | 
 **data** | **Object**| Provide your udc value data information to update | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="updateUdcValueTenant"></a>
# **updateUdcValueTenant**
> updateUdcValueTenant(tenantId, sysCode, typeId, valueId, data)

Update udc value resource with tenant by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.UdcValueApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var sysCode = "sysCode_example"; // String | Code of system to filter by

var typeId = "typeId_example"; // String | ID of udc type to filter by

var valueId = "valueId_example"; // String | ID of udc value to filter by

var data = null; // Object | Provide your udc value data information to update


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.updateUdcValueTenant(tenantId, sysCode, typeId, valueId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **sysCode** | **String**| Code of system to filter by | 
 **typeId** | **String**| ID of udc type to filter by | 
 **valueId** | **String**| ID of udc value to filter by | 
 **data** | **Object**| Provide your udc value data information to update | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

