# WorkEvolveApi.VersionApi

All URIs are relative to *http://localhost/websiteapi/sourcecode/public/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getAllVersions**](VersionApi.md#getAllVersions) | **POST** /tenants/{tenantId}/programs/{proId}/versions/get | Get all versions resource
[**getVersionById**](VersionApi.md#getVersionById) | **GET** /tenants/{tenantId}/programs/{proId}/versions/{versionId} | Get a version resource by id
[**removeVersionById**](VersionApi.md#removeVersionById) | **DELETE** /tenants/{tenantId}/programs/{proId}/versions/{versionId} | Delete version resource by id
[**saveVersion**](VersionApi.md#saveVersion) | **POST** /tenants/{tenantId}/programs/{proId}/versions | Save a new version resource
[**updateVersion**](VersionApi.md#updateVersion) | **POST** /tenants/{tenantId}/programs/{proId}/versions/{versionId} | Update version resource by id


<a name="getAllVersions"></a>
# **getAllVersions**
> getAllVersions(tenantId, proId, opts)

Get all versions resource

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.VersionApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var proId = "proId_example"; // String | ID of program to filter by

var opts = { 
  'filter': null, // Object | Filter versions by condition provided
  'offset': 0, // Number | The number of items to skip before starting to collect the result set
  'limit': 25 // Number | The number of items to return
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getAllVersions(tenantId, proId, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **proId** | **String**| ID of program to filter by | 
 **filter** | **Object**| Filter versions by condition provided | [optional] 
 **offset** | **Number**| The number of items to skip before starting to collect the result set | [optional] [default to 0]
 **limit** | **Number**| The number of items to return | [optional] [default to 25]

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getVersionById"></a>
# **getVersionById**
> getVersionById(tenantId, proId, versionId)

Get a version resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.VersionApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var proId = "proId_example"; // String | ID of program to filter by

var versionId = "versionId_example"; // String | ID of version to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.getVersionById(tenantId, proId, versionId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **proId** | **String**| ID of program to filter by | 
 **versionId** | **String**| ID of version to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="removeVersionById"></a>
# **removeVersionById**
> removeVersionById(tenantId, proId, versionId)

Delete version resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.VersionApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var proId = "proId_example"; // String | ID of program to filter by

var versionId = "versionId_example"; // String | ID of version to filter by


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.removeVersionById(tenantId, proId, versionId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **proId** | **String**| ID of program to filter by | 
 **versionId** | **String**| ID of version to filter by | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="saveVersion"></a>
# **saveVersion**
> saveVersion(tenantId, proId, data)

Save a new version resource

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.VersionApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var proId = "proId_example"; // String | ID of program to filter by

var data = null; // Object | Provide your version data information to save


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.saveVersion(tenantId, proId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **proId** | **String**| ID of program to filter by | 
 **data** | **Object**| Provide your version data information to save | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="updateVersion"></a>
# **updateVersion**
> updateVersion(tenantId, proId, versionId, data)

Update version resource by id

### Example
```javascript
var WorkEvolveApi = require('work_evolve_api');
var defaultClient = WorkEvolveApi.ApiClient.instance;

// Configure API key authorization: default
var default = defaultClient.authentications['default'];
default.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//default.apiKeyPrefix = 'Token';

var apiInstance = new WorkEvolveApi.VersionApi();

var tenantId = "tenantId_example"; // String | ID of tenant to filter by

var proId = "proId_example"; // String | ID of program to filter by

var versionId = "versionId_example"; // String | ID of version to filter by

var data = null; // Object | Provide your version data information to update


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully.');
  }
};
apiInstance.updateVersion(tenantId, proId, versionId, data, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tenantId** | **String**| ID of tenant to filter by | 
 **proId** | **String**| ID of program to filter by | 
 **versionId** | **String**| ID of version to filter by | 
 **data** | **Object**| Provide your version data information to update | 

### Return type

null (empty response body)

### Authorization

[default](../README.md#default)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

